@@ -71,6 +71,20 @@
 # define MB_LEN_MAX 16
 #endif
 
+#ifdef HAVE_FGETS_UNLOCKED
+# ifdef fgets
+#  undef fgets
+# endif
+# define fgets fgets_unlocked
+#endif
+
+#ifdef HAVE_FGETC_UNLOCKED
+# ifdef fgetc
+#  undef fgetc
+# endif
+# define fgetc fgetc_unlocked
+#endif
+
 /* nifty trick I stole from ELM 2.5alpha. */
 #ifdef MAIN_C
 #define WHERE 
@@ -239,6 +253,7 @@ enum
   MUTT_PGP_KEY,
   MUTT_XLABEL,
   MUTT_MIMEATTACH,
+  MUTT_MIMETYPE,
   
   /* Options for Mailcap lookup */
   MUTT_EDIT,
@@ -270,6 +285,7 @@ enum
 enum
 {
   OPT_ABORT,
+  OPT_ABORTNOATTACH,
   OPT_BOUNCE,
   OPT_COPY,
   OPT_DELETE,
@@ -341,7 +357,9 @@ enum
   OPTBEEP,
   OPTBEEPNEW,
   OPTBOUNCEDELIVERED,
+  OPTCHANGEFOLDERNEXT,
   OPTBRAILLEFRIENDLY,
+  OPTBROWSERABBRMAILBOXES,
   OPTCHECKMBOXSIZE,
   OPTCHECKNEW,
   OPTCOLLAPSEUNREAD,
@@ -476,7 +494,7 @@ enum
   OPTUSEDOMAIN,
   OPTUSEFROM,
   OPTUSEGPGAGENT,
-#ifdef HAVE_LIBIDN
+#if defined(HAVE_LIBIDN) || defined(HAVE_LIBIDN2)
   OPTIDNDECODE,
   OPTIDNENCODE,
 #endif
